#include "stdio.h"
#include "stdlib.h"

#include "config.h"
#include "uart.h"
#include "io.h"

#include "delays.h"

#include "signal.h"
#include "interrupt.h"

#include "rtc_ds1337.h"
#include "twi.h"
#include "timer.h";
#include "adc.h"
#include "comparator.h"

int main( void )
{
	unsigned long ulAdcValue = 0;
	static unsigned long ulOldAdcValue = 0;
	
	static UCHAR ucCount = 0;
	static unsigned long ulSum = 0;	

	double dVoltage = 0;

	UCHAR AdcStr[10];

	OSCCAL = CAL_VAL;

	DDRC 	= 0xFF;
	PORTC 	= 0xFF;
	
	USART_Init( UART_BAUD_CALC );

	// Initialize TWI
	//TWI_Master_Init();
	
	// Initialize RTC
	//TwiRTCInit();

	// Initialize Timer
	TimerInit();

	// Initialize Comparator
	InitComparator();

	// Enable interrupts
	sei();

	sDelay();

	CmdPrompt();
	Print( "Debug-Monitor for AVR" );
	CmdPrompt();
	Print( "-------------------------------" );
	CmdPrompt();
	
	// init ADC
	initADC();


	for(;;)
	{

		// Start conversion
		ADCSRA |= ( 1 << ADSC );

		// wait until ADSC becomes zero --> conversion's complete
		while( ADCSRA & ( 1 << ADSC ) );

		// make 16bit-value from two 8bit-Registers
		ulAdcValue = ( ADCL ) | ( ADCH << 8 );

		 
		if ( ucCount >= 16 )
		{
			ulAdcValue = (ulSum >> 4) + 0.5;
			ulSum = 0;
			ucCount = 0;


			if ( ulAdcValue != ulOldAdcValue )
			{
			
				//dVoltage = (MAX_VOLTAGE / 1023.f) * (double)ulAdcValue;

				#ifndef DISABLE_ADC_OUTPUT
				dtostrf( /*dVoltage*/ (double)ulAdcValue, 4, 4, AdcStr );
	
			
				USART_Transmit( CARRIAGE_RETURN );
				USART_Transmit( LINE_FEED );
				Print( AdcStr );
				#endif
			
			}

			ulOldAdcValue = ulAdcValue;
		}
			else
			{
				ulSum += ulAdcValue;
				ucCount++;
			}

	}
}
