
#include "types.h"
#include "rtc_ds1337.h"	
#include "twi.h"

/* calculates a decimal value from 2 single digits */
static UCHAR BCD2Dec( UCHAR ucBCD )
{
   return ( ( ucBCD >> 4 ) * 10 ) + ( ucBCD & 0x0F );
}


/* splits a decimal value into 2 single digits */
static UCHAR Dec2BCD( UCHAR ucDec )
{
   return ( (ucDec / 10) << 4 ) | (ucDec % 10);
}


UINT16 TwiRTCSetClock( pSTRUCT_TWI_RTC psRTC )
{
   UINT16 ui16Status = 0;
   UCHAR aucRTCData[7];

   aucRTCData[0] = Dec2BCD(psRTC->ucSeconds);;
   aucRTCData[1] = Dec2BCD(psRTC->ucMinutes);
   aucRTCData[2] = Dec2BCD(psRTC->ucHours);
   aucRTCData[3] = psRTC->ucDayOfWeek;
   aucRTCData[4] = Dec2BCD(psRTC->ucDay);
   aucRTCData[5] = Dec2BCD(psRTC->ucMonth) & 0x1F;
   aucRTCData[6] = Dec2BCD(psRTC->ucYear);

   ui16Status  = TwiIOWrite( RTC_SLAVE_ADDR, REG_SECONDS, aucRTCData, 7 );

   return ui16Status;
}


UINT16 TwiRTCGetClock( pSTRUCT_TWI_RTC psRTC )
{
   UINT16 ui16Status = 0;

   #ifdef READ_SINGLE_BYTES
      UCHAR ucSec;
      UCHAR ucMin;
      UCHAR ucHour;
      UCHAR ucDayOfWeek;
      UCHAR ucDay;
      UCHAR ucMonth;
      UCHAR ucYear;

      ui16Status  = TwiIORead( RTC_SLAVE_ADDR, REG_SECONDS, &ucSec, 1 );
      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_MINUTES, &ucMin, 1 );
      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_HOURS, &ucHour, 1 );

      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_DAY_OF_WEEK, &ucDayOfWeek, 1 );
      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_DAY, &ucDay, 1 );
      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_MONTH, &ucMonth, 1 );
      ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_YEAR, &ucYear, 1 );

      psRTC->ucSeconds   = BCD2Dec(ucSec);
      psRTC->ucMinutes   = BCD2Dec(ucMin);
      psRTC->ucHours     = BCD2Dec(ucHour);

      psRTC->ucDayOfWeek = ucDayOfWeek;
      psRTC->ucDay       = BCD2Dec(ucDay);
      psRTC->ucMonth     = BCD2Dec(ucMonth) & 0x1F;
      psRTC->ucYear      = BCD2Dec(ucYear);

   #else
      UCHAR ucRTCData[7];


      ui16Status  = TwiIORead( RTC_SLAVE_ADDR, REG_SECONDS, ucRTCData, 7 );

      psRTC->ucSeconds   = BCD2Dec(ucRTCData[0]);
      psRTC->ucMinutes   = BCD2Dec(ucRTCData[1]);
      psRTC->ucHours     = BCD2Dec(ucRTCData[2]);

      psRTC->ucDayOfWeek = ucRTCData[3];
      psRTC->ucDay       = BCD2Dec(ucRTCData[4]);
      psRTC->ucMonth     = BCD2Dec(ucRTCData[5]) & 0x1F;
      psRTC->ucYear      = BCD2Dec(ucRTCData[6]);
   #endif

   return ui16Status;
}


UINT16 TwiRTCInit( void )
{
   UCHAR ucConfig;
   UINT16 ui16Status = 0;

   /* test */
   ucConfig = 0;

   ui16Status = TwiIOWrite( RTC_SLAVE_ADDR, CONTROL_REGISTER, &ucConfig, 1 );

   /* Set 24h Mode */
   ui16Status |= TwiIORead( RTC_SLAVE_ADDR, REG_HOURS, &ucConfig, 1 );
   ucConfig &= HOURS_24;
   ui16Status |= TwiIOWrite( RTC_SLAVE_ADDR, REG_HOURS, &ucConfig, 1 );

   return ui16Status;
}
