#ifndef _TWIRTC_
#define _TWIRTC_

/* RTC I2C Slave Address */
#define RTC_SLAVE_ADDR					0x68

/* Complete I2C-Read for every register (slow) */
//#define READ_SINGLE_BYTES

/*==========================================================================*
 *		              Register definitions for MAXIM DS1337 I2c RTC
 *==========================================================================*/

/* Time/Date */
#define REG_SECONDS						0x00
#define REG_MINUTES						0x01
#define REG_HOURS						0x02
#define REG_DAY_OF_WEEK 				0x03
#define REG_DAY							0x04
#define REG_MONTH						0x05
#define REG_YEAR						0x06

/* Alarm 1 */
#define REG_SECONDS_ALARM_1			   	0x07
#define REG_MINUTES_ALARM_1			   	0x08
#define REG_HOURS_ALARM_1				0x09
#define REG_DAY_DATE_ALARM_1		    0x0A

/* Alarm 2 */
#define REG_MINUTES_ALARM_2			   	0x0B
#define REG_HOURS_ALARM_2				0x0C
#define REG_DAY_DATE_ALARM_2		    0x0D

/* Special Purpose Registers */
#define	CONTROL_REGISTER				0x0E
#define	STATUS_REGISTER					0x0F


/*==========================================================================*
 *		              Commands
 *==========================================================================*/

#define HOURS_12						(UCHAR)( 1 << 6 )
#define HOURS_24						~((UCHAR)( 1 << 6 ))

#define PM								(UCHAR)( 1 << 5 )
#define AM								~((UCHAR)( 1 << 5 ))

#define DISABLE_OSC						(UCHAR)( 1 << 7 )
#define ENABLE_OSC						~((UCHAR)( 1 << 7 ))

#define RATE_SELECT_2					(UCHAR)( 1 << 4 )
#define RATE_SELECT_1					(UCHAR)( 1 << 3 )

#define INT_CTRL						(UCHAR)( 1 << 2 )
#define ALARM_2_INT						(UCHAR)( 1 << 1 )
#define ALARM_1_INT						(UCHAR)( 1 << 0 )


/*==========================================================================*
 *		              Status Register Flags
 *==========================================================================*/

#define OSC_STOP_FLAG					(UCHAR)( 1 << 7 )
#define ALARM_2_FLAG 					(UCHAR)( 1 << 1 )
#define ALARM_1_FLAG					(UCHAR)( 1 << 0 )


/*==========================================================================*
 *		              date time structure
 *==========================================================================*/
typedef struct
{
   //UCHAR ucCentury;
   UCHAR ucYear;
   UCHAR ucMonth;
   UCHAR ucDay;
   UCHAR ucDayOfWeek;
   UCHAR ucHours;
   UCHAR ucMinutes;
   UCHAR ucSeconds;

} STRUCT_TWI_RTC, *pSTRUCT_TWI_RTC;


/*==========================================================================*
 *		              function prototypes
 *==========================================================================*/

UINT16 TwiRTCSetClock( pSTRUCT_TWI_RTC psRTC );
UINT16 TwiRTCGetClock( pSTRUCT_TWI_RTC psRTC );
UINT16 TwiRTCInit( void );

#endif /*_TWIRTC_*/
