#include "io.h"
#include "types.h"

#include "signal.h"
#include "interrupt.h"

#include "stdio.h"

#include "config.h"
#include "uart.h"
#include "timer.h"
#include "comparator.h"



void TimerInit( void )
{
	//UCHAR hb, lb;

	TCCR1B = (1<<CS12) | (0<<CS11) | (0<<CS10); 	// Timer clock =
													// system clock/256
	
	
	TIFR = 1<<ICF1; // Clear ICF1/
					// clear pending
					// interrupts
	
	
	TIMSK = 1 << OCIE1A; 	// Enable Timer1
							// Compare Event
							// Interrupt

	//hb = (UCHAR) ( (31250 & 0xFF00)>>8 );
	//lb = (UCHAR) ( 31250 & 0x00FF );

	//OCR1AH = 0x7A;
	//OCR1AL = 0x12;
	
    
	OCR1AH = (UCHAR) ( (31250 & 0xFF00)>>8 );
	OCR1AL = (UCHAR) ( 31250 & 0x00FF );
	
}


// Timer-ISR
SIGNAL( SIG_OUTPUT_COMPARE1A )
{
	static UCHAR toggle = 0;
	UCHAR FreqStr[10];

	#ifdef TIMER_BLINK
	if ( !toggle )
	{
		// turn LED0 on, LED0 off
		PORTC &= ~(1<<PINC0); 
		PORTC |=  (1<<PINC1);
		toggle = 0x01;
	}
		else
		{
			// turn LED0 off, LED0 on	
			PORTC |=  (1<<PINC0);
			PORTC &= ~(1<<PINC1);  
			toggle = 0x00;
		}
	#endif

	TCNT1 = 0; 	// Reset Timer1 Count
				// Register

	#ifndef DISABLE_TIMER_OUTPUT
	sprintf( FreqStr, "%i", GetFrequencyCounter() ); 
	
	
	USART_Transmit( CARRIAGE_RETURN );
	USART_Transmit( LINE_FEED );
	Print( FreqStr );
	#endif

	ClearFrequencyCounter();
}
