
/* Includes */
#include "io.h"
#include "uart.h"
#include "types.h"
#include "string.h"
#include "config.h"
#include "signal.h"
#include "interrupt.h"
#include "CmdInterpreter.h"


/* globale Variablen */
UCHAR rec_buffer[32];


/* Initialize UART */
void USART_Init( unsigned int baudrate )
{
	/* Set the baud rate */
	UBRRH = (unsigned char) (baudrate>>8);                  
	UBRRL = (unsigned char) baudrate;
	
	/* Enable UART receiver and transmitter */
	UCSRB = ( ( 1 << RXEN ) | ( 1 << TXEN ) ); 
	
	/* Set frame format: 8 data 2stop */
	UCSRB |= (1<<URSEL)|(1<<USBS)|(3<<UCSZ0)|( 1 << RXCIE );
}

/*------------------------------------*/
/* Interrupt-Routine fr UART-Empfang */
/*------------------------------------*/
SIGNAL( SIG_USART_RECV )
{
	UCHAR rec_data; 
	static UINT16 char_count = 0;

	rec_data = UDR;

	USART_Transmit( rec_data );

	if ( ( rec_data == CARRIAGE_RETURN ) || ( char_count >= 30 ) )
	{
		BOOL CmdExecuted;

		rec_buffer[ char_count ] = '\0';

		CmdExecuted = CmdInterpreter( &rec_buffer[0] );

		CmdPrompt();
		
		#ifdef DEBUG	
		  /* for debugging only */
		  Print( &rec_buffer[0] );
		  CmdPrompt();
		#endif

		if ( !CmdExecuted )
		{
			if ( char_count )
			{ 
				Print( "Unknown Command" );
				CmdPrompt();
			}

		}

		char_count = 0;
	}
		else
		{
			rec_buffer[ char_count ] = rec_data;
			char_count++;
		}	
}

/* WRITE */
void USART_Transmit( unsigned char data )
{
	/* Wait for empty transmit buffer */
	while ( !(UCSRA & (1<<UDRE)) )
		; 			                
	/* Start transmittion */
	UDR = data; 			        
}

void CmdPrompt( void )
{
	USART_Transmit( LINE_FEED );
	USART_Transmit( CARRIAGE_RETURN );
	USART_Transmit( '>' );
}

/* String senden */
void Print( string Str2Send )
{
	UINT16 i;
	UINT16 StrSize;

	StrSize = strlen(Str2Send);

	//USART_Transmit( LINE_FEED );
	
	for ( i=0; i < StrSize; i++ )
	{	
		USART_Transmit( *Str2Send++ );
	}

}
